@@ -21,12 +21,14 @@
 #include "ui_itemtagssettings.h"
 
 #include "common/command.h"
+#include "common/compatibility.h"
 #include "common/contenttype.h"
 #include "common/regexp.h"
 #include "common/textdata.h"
 #include "gui/iconfont.h"
 #include "gui/iconselectbutton.h"
 #include "gui/pixelratio.h"
+#include "item/itemfilter.h"
 
 #ifdef HAS_TESTS
 #   include "tests/itemtagstests.h"
@@ -35,6 +37,7 @@
 #include <QBoxLayout>
 #include <QColorDialog>
 #include <QLabel>
+#include <QMessageBox>
 #include <QModelIndex>
 #include <QPainter>
 #include <QPixmap>
@@ -43,13 +46,15 @@
 #include <QtPlugin>
 #include <QUrl>
 
+#include <memory>
+
 Q_DECLARE_METATYPE(ItemTags::Tag)
 
 namespace {
 
-const char mimeTags[] = "application/x-copyq-tags";
+const QLatin1String mimeTags("application/x-copyq-tags");
 
-const char configTags[] = "tags";
+const QLatin1String configTags("tags");
 
 const char propertyColor[] = "CopyQ_color";
 
@@ -59,7 +64,8 @@ enum {
     match,
     styleSheet,
     color,
-    icon
+    icon,
+    lock
 };
 }
 
@@ -94,7 +100,7 @@ QString serializeColor(const QColor &color)
     if (color.alpha() == 255)
         return color.name();
 
-    return QString("rgba(%1,%2,%3,%4)")
+    return QString::fromLatin1("rgba(%1,%2,%3,%4)")
             .arg(color.red())
             .arg(color.green())
             .arg(color.blue())
@@ -127,7 +133,7 @@ void setColorIcon(QPushButton *button, const QColor &color)
 void setFixedColumnSize(QTableWidget *table, int logicalIndex)
 {
     table->horizontalHeader()->setSectionResizeMode(logicalIndex, QHeaderView::Fixed);
-    table->horizontalHeader()->resizeSection(logicalIndex, table->rowHeight(0));
+    table->resizeColumnToContents(logicalIndex);
 }
 
 QVariant cellWidgetProperty(QTableWidget *table, int row, int column, const char *property)
@@ -138,7 +144,7 @@ QVariant cellWidgetProperty(QTableWidget *table, int row, int column, const char
 QStringList tags(const QVariant &tags)
 {
     return getTextData( tags.toByteArray() )
-            .split(',', QString::SkipEmptyParts);
+            .split(',', SKIP_EMPTY_PARTS);
 }
 
 QStringList tags(const QVariantMap &itemData)
@@ -279,6 +285,27 @@ ItemTags::Tag findMatchingTag(const QString &tagText, const ItemTags::Tags &tags
     return ItemTags::Tag();
 }
 
+bool isLocked(const QModelIndex &index, const ItemTags::Tags &tags)
+{
+    const auto dataMap = index.data(contentType::data).toMap();
+    const auto itemTags = ::tags(dataMap);
+    return std::any_of(
+        std::begin(itemTags), std::end(itemTags),
+        [&tags](const QString &itemTag){
+            const auto tag = findMatchingTag(itemTag, tags);
+            return tag.lock;
+        });
+}
+
+bool containsLockedItems(const QModelIndexList &indexList, const ItemTags::Tags &tags)
+{
+    return std::any_of(
+        std::begin(indexList), std::end(indexList),
+        [&tags](const QModelIndex &index){
+            return isLocked(index, tags);
+        });
+}
+
 class TagTableWidgetItem final : public QTableWidgetItem
 {
 public:
@@ -574,6 +601,40 @@ bool ItemTagsScriptable::removeTag(const QString &tagName, QStringList *tags)
     return true;
 }
 
+ItemTagsSaver::ItemTagsSaver(const ItemTags::Tags &tags, const ItemSaverPtr &saver)
+    : ItemSaverWrapper(saver)
+    , m_tags(tags)
+{
+}
+
+bool ItemTagsSaver::canRemoveItems(const QList<QModelIndex> &indexList, QString *error)
+{
+    if ( !containsLockedItems(indexList, m_tags) )
+        return ItemSaverWrapper::canRemoveItems(indexList, error);
+
+    if (error) {
+        *error = "Removing items with locked tags is not allowed (untag items first)";
+        return false;
+    }
+
+    QMessageBox::information(
+                QApplication::activeWindow(),
+                ItemTagsLoader::tr("Cannot Remove Items With a Locked Tag"),
+                ItemTagsLoader::tr("Untag items first to remove them.") );
+    return false;
+}
+
+bool ItemTagsSaver::canDropItem(const QModelIndex &index)
+{
+    return !isLocked(index, m_tags) && ItemSaverWrapper::canDropItem(index);
+}
+
+bool ItemTagsSaver::canMoveItems(const QList<QModelIndex> &indexList)
+{
+    return !containsLockedItems(indexList, m_tags)
+            && ItemSaverWrapper::canMoveItems(indexList);
+}
+
 ItemTagsLoader::ItemTagsLoader()
     : m_blockDataChange(false)
 {
@@ -635,6 +696,7 @@ QWidget *ItemTagsLoader::createSettingsWidget(QWidget *parent)
     header->setSectionResizeMode(tagsTableColumns::match, QHeaderView::Stretch);
     setFixedColumnSize(ui->tableWidget, tagsTableColumns::color);
     setFixedColumnSize(ui->tableWidget, tagsTableColumns::icon);
+    setFixedColumnSize(ui->tableWidget, tagsTableColumns::lock);
 
     connect( ui->tableWidget, &QTableWidget::itemChanged,
              this, &ItemTagsLoader::onTableWidgetItemChanged );
@@ -652,12 +714,21 @@ ItemWidget *ItemTagsLoader::transform(ItemWidget *itemWidget, const QVariantMap
     return new ItemTags(itemWidget, tags);
 }
 
-bool ItemTagsLoader::matches(const QModelIndex &index, const QRegularExpression &re) const
+ItemSaverPtr ItemTagsLoader::transformSaver(const ItemSaverPtr &saver, QAbstractItemModel *)
+{
+    // Avoid checking for locked items if no locked tags are specified in configuration.
+    const bool hasAnyLocks = std::any_of(
+        std::begin(m_tags), std::end(m_tags),
+        [](const ItemTags::Tag &tag){ return tag.lock; });
+    return hasAnyLocks ? std::make_shared<ItemTagsSaver>(m_tags, saver) : saver;
+}
+
+bool ItemTagsLoader::matches(const QModelIndex &index, const ItemFilter &filter) const
 {
     const QByteArray tagsData =
             index.data(contentType::data).toMap().value(mimeTags).toByteArray();
     const auto tags = getTextData(tagsData);
-    return tags.contains(re);
+    return filter.matches(tags);
 }
 
 QObject *ItemTagsLoader::tests(const TestInterfacePtr &test) const
@@ -678,7 +749,7 @@ QObject *ItemTagsLoader::tests(const TestInterfacePtr &test) const
     tests->setProperty("CopyQ_test_settings", settings);
     return tests;
 #else
-    Q_UNUSED(test);
+    Q_UNUSED(test)
     return nullptr;
 #endif
 }
@@ -776,7 +847,8 @@ QString ItemTagsLoader::serializeTag(const ItemTagsLoader::Tag &tag)
             + ";;" + escapeTagField(tag.color)
             + ";;" + escapeTagField(tag.icon)
             + ";;" + escapeTagField(tag.styleSheet)
-            + ";;" + escapeTagField(tag.match);
+            + ";;" + escapeTagField(tag.match)
+            + ";;" + (tag.lock ? "L" : "");
 }
 
 ItemTagsLoader::Tag ItemTagsLoader::deserializeTag(const QString &tagText)
@@ -789,6 +861,7 @@ ItemTagsLoader::Tag ItemTagsLoader::deserializeTag(const QString &tagText)
     tag.icon = unescapeTagField(tagFields.value(2));
     tag.styleSheet = unescapeTagField(tagFields.value(3));
     tag.match = unescapeTagField(tagFields.value(4));
+    tag.lock = unescapeTagField(tagFields.value(5)) == QLatin1String("L");
 
     return tag;
 }
@@ -835,6 +908,10 @@ void ItemTagsLoader::addTagToSettingsTable(const ItemTagsLoader::Tag &tag)
     t->setItem( row, tagsTableColumns::color, new QTableWidgetItem() );
     t->setItem( row, tagsTableColumns::icon, new QTableWidgetItem() );
 
+    auto lock = new QTableWidgetItem();
+    lock->setCheckState(tag.lock ? Qt::Checked : Qt::Unchecked);
+    t->setItem( row, tagsTableColumns::lock, lock );
+
     auto colorButton = new QPushButton(t);
     const QColor color = tag.color.isEmpty()
             ? QColor::fromRgb(50, 50, 50)
@@ -863,5 +940,6 @@ ItemTagsLoader::Tag ItemTagsLoader::tagFromTable(int row)
     tag.icon = cellWidgetProperty(t, row, tagsTableColumns::icon, "currentIcon").toString();
     tag.styleSheet = t->item(row, tagsTableColumns::styleSheet)->text();
     tag.match = t->item(row, tagsTableColumns::match)->text();
+    tag.lock = t->item(row, tagsTableColumns::lock)->checkState() == Qt::Checked;
     return tag;
 }
