@@ -32,7 +32,7 @@
 
 #include <QApplication>
 #include <QFile>
-#include <QScriptEngine>
+#include <QJSEngine>
 #include <QSettings>
 #include <QThread>
 #include <QTimer>
@@ -51,7 +51,7 @@ QString messageCodeToString(int code)
     case CommandData:
         return "CommandData";
     default:
-        return QString("Unknown(%1)").arg(code);
+        return QString::fromLatin1("Unknown(%1)").arg(code);
     }
 }
 
@@ -59,7 +59,6 @@ QCoreApplication *createClientApplication(int &argc, char **argv, const QStringL
 {
     // Clipboard access requires QApplication.
     if ( arguments.size() > 1 && arguments[0] == "--clipboard-access" ) {
-        QGuiApplication::setDesktopSettingsAware(false);
         const auto app = platformNativeInterface()
                 ->createClipboardProviderApplication(argc, argv);
         setLogLabel(arguments[1].toUtf8());
@@ -133,7 +132,7 @@ void ClipboardClient::onConnectionFailed()
 
 void ClipboardClient::start(const QStringList &arguments)
 {
-    QScriptEngine engine;
+    QJSEngine engine;
     ScriptableProxy scriptableProxy(nullptr, nullptr);
     Scriptable scriptable(&engine, &scriptableProxy);
 
@@ -184,6 +183,7 @@ void ClipboardClient::start(const QStringList &arguments)
         scriptable.setActionName(actionName);
 
         const int exitCode = scriptable.executeArguments(arguments);
+        socket.disconnect(&scriptable);
         exit(exitCode);
     }
 }
