@@ -134,8 +134,6 @@ private:
 
     void sendActionData(int actionId, const QByteArray &bytes);
 
-    void updateNotifications();
-
     Server *m_server = nullptr;
     MainWindow* m_wnd = nullptr;
     QPointer<Action> m_monitor;
@@ -144,6 +142,7 @@ private:
     bool m_ignoreNewConnections = false;
     QMap<QxtGlobalShortcut*, Command> m_shortcutActions;
     QTimer m_ignoreKeysTimer;
+    QTimer m_updateThemeTimer;
     uint m_monitorCommandsStateHash = 0;
     int m_textTabSize = 8;
     bool m_saveOnDeactivate = true;
