@@ -26,6 +26,7 @@
 #include "gui/theme.h"
 #include "item/clipboardmodel.h"
 #include "item/itemdelegate.h"
+#include "item/itemfilter.h"
 #include "item/itemwidget.h"
 
 #include <QListView>
@@ -139,6 +140,8 @@ class ClipboardBrowser final : public QListView
                 int row = 0 //!< Target row for the new item (negative to append item).
                 );
 
+        bool addAndSelect(const QVariantMap &data, int row);
+
         /**
          * Add item and remove duplicates.
          */
@@ -154,7 +157,7 @@ class ClipboardBrowser final : public QListView
         /** Move items to clipboard. */
         void moveToClipboard(const QModelIndexList &indexes);
         /** Show only items matching the regular expression. */
-        void filterItems(const QRegularExpression &re);
+        void filterItems(const ItemFilterPtr &filter);
         /** Open editor. */
         bool openEditor(const QByteArray &textData, bool changeClipboard = false);
         /** Open editor for an item. */
@@ -406,6 +409,8 @@ class ClipboardBrowser final : public QListView
         QPoint m_dragStartPosition;
 
         int m_filterRow = -1;
+
+        bool m_selectNewItems = false;
 };
 
 #endif // CLIPBOARDBROWSER_H
