@@ -92,7 +92,7 @@ public:
         , m_reFunctions(createRegExp(scriptableFunctions()))
         , m_reKeywords(createRegExp(scriptableKeywords()))
         , m_reLabels(commandLabelRegExp())
-        , m_reNumbers("(?:\\b|%)\\d+")
+        , m_reConstants("\\b0x[0-9A-Fa-f]+|(?:\\b|%)\\d+|\\btrue\\b|\\bfalse\\b")
     {
     }
 
@@ -123,9 +123,9 @@ protected:
         labelsFormat.setForeground(mixColor(m_bgColor, 40, 40, -40));
         highlight(text, m_reLabels, labelsFormat);
 
-        QTextCharFormat numberFormat;
-        numberFormat.setForeground(mixColor(m_bgColor, 40, -40, -40));
-        highlight(text, m_reNumbers, numberFormat);
+        QTextCharFormat constantFormat;
+        constantFormat.setForeground(mixColor(m_bgColor, 40, -40, -40));
+        highlight(text, m_reConstants, constantFormat);
 
         highlightBlocks(text);
     }
@@ -244,43 +244,66 @@ private:
     QRegularExpression m_reFunctions;
     QRegularExpression m_reKeywords;
     QRegularExpression m_reLabels;
-    QRegularExpression m_reNumbers;
+    QRegularExpression m_reConstants;
     QColor m_bgColor;
 };
 
+bool isPublicName(const QString &name)
+{
+    return !name.startsWith('_');
+}
+
+QStringList getScriptableObjects()
+{
+    QJSEngine engine;
+    Scriptable scriptable(&engine, nullptr);
+
+    QJSValue globalObject = engine.globalObject();
+    QJSValueIterator it(globalObject);
+
+    QStringList result;
+    while (it.hasNext()) {
+        it.next();
+        if ( isPublicName(it.name()) )
+            result.append(it.name());
+    }
+
+    return result;
+}
+
 } // namespace
 
 QStringList scriptableKeywords()
 {
-    return QStringList()
-            << "arguments"
-            << "break"
-            << "do"
-            << "instanceof"
-            << "typeof"
-            << "case"
-            << "else"
-            << "new"
-            << "var"
-            << "catch"
-            << "finally"
-            << "return"
-            << "void"
-            << "continue"
-            << "for"
-            << "switch"
-            << "while"
-            << "debugger"
-            << "function"
-            << "this"
-            << "with"
-            << "default"
-            << "if"
-            << "throw"
-            << "delete"
-            << "in"
-            << "try"
-               ;
+    return {
+        QStringLiteral("arguments"),
+        QStringLiteral("break"),
+        QStringLiteral("do"),
+        QStringLiteral("instanceof"),
+        QStringLiteral("typeof"),
+        QStringLiteral("case"),
+        QStringLiteral("else"),
+        QStringLiteral("new"),
+        QStringLiteral("var"),
+        QStringLiteral("catch"),
+        QStringLiteral("finally"),
+        QStringLiteral("return"),
+        QStringLiteral("void"),
+        QStringLiteral("continue"),
+        QStringLiteral("for"),
+        QStringLiteral("switch"),
+        QStringLiteral("while"),
+        QStringLiteral("debugger"),
+        QStringLiteral("function"),
+        QStringLiteral("this"),
+        QStringLiteral("with"),
+        QStringLiteral("default"),
+        QStringLiteral("if"),
+        QStringLiteral("throw"),
+        QStringLiteral("delete"),
+        QStringLiteral("in"),
+        QStringLiteral("try"),
+    };
 }
 
 QStringList scriptableProperties()
@@ -290,7 +313,8 @@ QStringList scriptableProperties()
     QMetaObject scriptableMetaObject = Scriptable::staticMetaObject;
     for (int i = 0; i < scriptableMetaObject.propertyCount(); ++i) {
         QMetaProperty property = scriptableMetaObject.property(i);
-        result.append(property.name());
+        if ( isPublicName(property.name()) )
+            result.append(property.name());
     }
 
     result.removeOne("objectName");
@@ -308,7 +332,8 @@ QStringList scriptableFunctions()
 
         if (method.methodType() == QMetaMethod::Slot && method.access() == QMetaMethod::Public) {
             const QString name = methodName(method);
-            result.append(name);
+            if ( isPublicName(name) )
+                result.append(name);
         }
     }
 
@@ -319,22 +344,7 @@ QStringList scriptableFunctions()
 
 QStringList scriptableObjects()
 {
-    QStringList result;
-    result.append("ByteArray");
-    result.append("Dir");
-    result.append("File");
-    result.append("TemporaryFile");
-
-    QJSEngine engine;
-
-    QJSValue globalObject = engine.globalObject();
-    QJSValueIterator it(globalObject);
-
-    while (it.hasNext()) {
-        it.next();
-        result.append(it.name());
-    }
-
+    static const QStringList result = getScriptableObjects();
     return result;
 }
 
