@@ -25,8 +25,8 @@
 #include "common/contenttype.h"
 #include "common/log.h"
 #include "common/mimetypes.h"
-#include "common/regexp.h"
 #include "common/textdata.h"
+#include "item/itemfilter.h"
 #include "item/itemstore.h"
 #include "item/itemwidget.h"
 #include "item/serialize.h"
@@ -47,6 +47,12 @@ namespace {
 
 bool findPluginDir(QDir *pluginsDir)
 {
+#ifdef COPYQ_PLUGIN_PREFIX
+    pluginsDir->setPath(COPYQ_PLUGIN_PREFIX);
+    if ( pluginsDir->isReadable() )
+        return true;
+#endif
+
     return platformNativeInterface()->findPluginDir(pluginsDir)
             && pluginsDir->isReadable();
 }
@@ -112,7 +118,9 @@ public:
     DummyItem(const QVariantMap &data, QWidget *parent, bool preview)
         : QLabel(parent)
         , ItemWidget(this)
-        , m_hasText( data.contains(mimeText) || data.contains(mimeUriList) )
+        , m_hasText( data.contains(mimeText)
+                  || data.contains(mimeTextUtf8)
+                  || data.contains(mimeUriList) )
         , m_data(data)
         , m_preview(preview)
     {
@@ -130,7 +138,7 @@ public:
             trySetPixmap(this, m_data, height);
         }
 
-        if (preview && !pixmap()) {
+        if (preview && !hasPixmap()) {
             setTextInteractionFlags(
                     textInteractionFlags()
                     | Qt::TextSelectableByMouse
@@ -152,7 +160,7 @@ public:
     {
         setFixedWidth(idealWidth);
 
-        if (!m_preview && !pixmap()) {
+        if (!m_preview && !hasPixmap()) {
             const int width = contentsRect().width();
             const QString label =
                     textLabelForData(m_data, font(), QString(), false, width, 1);
@@ -166,6 +174,15 @@ public:
     }
 
 private:
+    bool hasPixmap() const
+    {
+#if QT_VERSION >= QT_VERSION_CHECK(5,15,0)
+        return !pixmap(Qt::ReturnByValue).isNull();
+#else
+        return pixmap() != nullptr;
+#endif
+    }
+
     bool m_hasText;
     QVariantMap m_data;
     QString m_imageFormat;
@@ -215,10 +232,10 @@ public:
         return std::make_shared<DummySaver>();
     }
 
-    bool matches(const QModelIndex &index, const QRegularExpression &re) const override
+    bool matches(const QModelIndex &index, const ItemFilter &filter) const override
     {
         const QString text = index.data(contentType::text).toString();
-        return text.contains(re);
+        return filter.matches(text);
     }
 };
 
@@ -353,6 +370,8 @@ QStringList ItemFactory::formatsToSave() const
         formats.append(mimeItemNotes);
     if ( !formats.contains(mimeItems) )
         formats.append(mimeItems);
+    if ( !formats.contains(mimeTextUtf8) )
+        formats.append(mimeTextUtf8);
 
     return formats;
 }
@@ -416,39 +435,38 @@ ItemSaverPtr ItemFactory::initializeTab(const QString &tabName, QAbstractItemMod
     return nullptr;
 }
 
-bool ItemFactory::matches(const QModelIndex &index, const QRegularExpression &re) const
+bool ItemFactory::matches(const QModelIndex &index, const ItemFilter &filter) const
 {
-    // Match formats if the filter expression contains single '/'.
-    if (re.pattern().count('/') == 1) {
-        const auto re2 = anchoredRegExp(re.pattern());
-        const QVariantMap data = index.data(contentType::data).toMap();
-        for (auto it = data.constBegin(); it != data.constEnd(); ++it) {
-            if ( it.key().contains(re2) )
-                return true;
-        }
-    }
+    if ( filter.matchesIndex(index) )
+        return true;
 
     for ( const auto &loader : enabledLoaders() ) {
-        if ( isLoaderEnabled(loader) && loader->matches(index, re) )
+        if ( isLoaderEnabled(loader) && loader->matches(index, filter) )
             return true;
     }
 
     return false;
 }
 
-QList<ItemScriptable*> ItemFactory::scriptableObjects() const
+ItemScriptable *ItemFactory::scriptableObject(const QString &name) const
 {
-    QList<ItemScriptable*> scriptables;
+    QDir pluginsDir;
+    if ( !findPluginDir(&pluginsDir) )
+        return nullptr;
 
-    for ( const auto &loader : enabledLoaders() ) {
-        auto scriptable = loader->scriptableObject();
-        if (scriptable) {
-            scriptable->setObjectName(loader->id());
-            scriptables.append(scriptable);
+    const QStringList nameFilters( QString::fromLatin1("*%1*").arg(name) );
+    for (const auto &fileName : pluginsDir.entryList(nameFilters, QDir::Files)) {
+        const QString path = pluginsDir.absoluteFilePath(fileName);
+        auto loader = loadPlugin(path, name);
+        if (loader) {
+            QSettings settings;
+            settings.beginGroup("Plugins");
+            loadItemFactorySettings(loader, &settings);
+            return loader->scriptableObject();
         }
     }
 
-    return scriptables;
+    return nullptr;
 }
 
 QVector<Command> ItemFactory::commands(bool enabled) const
@@ -485,32 +503,15 @@ void ItemFactory::loaderChildDestroyed(QObject *obj)
 
 bool ItemFactory::loadPlugins()
 {
-#ifdef COPYQ_PLUGIN_PREFIX
-    QDir pluginsDir(COPYQ_PLUGIN_PREFIX);
-    if ( !pluginsDir.isReadable() && !findPluginDir(&pluginsDir))
-        return false;
-#else
     QDir pluginsDir;
-    if ( !findPluginDir(&pluginsDir))
+    if ( !findPluginDir(&pluginsDir) )
         return false;
-#endif
 
     for (const auto &fileName : pluginsDir.entryList(QDir::Files)) {
-        if ( QLibrary::isLibrary(fileName) ) {
-            const QString path = pluginsDir.absoluteFilePath(fileName);
-            QPluginLoader pluginLoader(path);
-            QObject *plugin = pluginLoader.instance();
-            COPYQ_LOG_VERBOSE( QString("Loading plugin: %1").arg(path) );
-            if (plugin == nullptr) {
-                log( pluginLoader.errorString(), LogError );
-            } else {
-                ItemLoaderPtr loader( qobject_cast<ItemLoaderInterface *>(plugin) );
-                if (loader == nullptr)
-                    pluginLoader.unload();
-                else
-                    addLoader(loader);
-            }
-        }
+        const QString path = pluginsDir.absoluteFilePath(fileName);
+        auto loader = loadPlugin(path, QString());
+        if (loader)
+            addLoader(loader);
     }
 
     std::sort(m_loaders.begin(), m_loaders.end(), priorityLessThan);
@@ -523,16 +524,8 @@ void ItemFactory::loadItemFactorySettings(QSettings *settings)
     // load settings for each plugin
     settings->beginGroup("Plugins");
     for ( auto &loader : loaders() ) {
-        settings->beginGroup(loader->id());
-
-        QVariantMap s;
-        for (const auto &name : settings->allKeys()) {
-            s[name] = settings->value(name);
-        }
-        setLoaderEnabled( loader, settings->value("enabled", true).toBool() );
-        loader->loadSettings(s);
-
-        settings->endGroup();
+        const bool enabled = loadItemFactorySettings(loader, settings);
+        setLoaderEnabled(loader, enabled);
     }
     settings->endGroup();
 
@@ -615,3 +608,43 @@ void ItemFactory::addLoader(const ItemLoaderPtr &loader)
             connect( signaler, SIGNAL(addCommands(QVector<Command>)), this, SIGNAL(addCommands(QVector<Command>)) );
     }
 }
+
+ItemLoaderPtr ItemFactory::loadPlugin(const QString &path, const QString &id) const
+{
+    if ( !QLibrary::isLibrary(path) )
+        return ItemLoaderPtr();
+
+    COPYQ_LOG_VERBOSE( QString("Loading plugin: %1").arg(path) );
+    QPluginLoader pluginLoader(path);
+    QObject *plugin = pluginLoader.instance();
+    if (plugin == nullptr) {
+        log( pluginLoader.errorString(), LogError );
+        return ItemLoaderPtr();
+    }
+
+    ItemLoaderPtr loader( qobject_cast<ItemLoaderInterface *>(plugin) );
+    if ( loader == nullptr || (!id.isEmpty() && id != loader->id()) ) {
+        COPYQ_LOG_VERBOSE( QString("Unloading plugin: %1").arg(path) );
+        loader = nullptr;
+        pluginLoader.unload();
+        return ItemLoaderPtr();
+    }
+
+    return loader;
+}
+
+bool ItemFactory::loadItemFactorySettings(const ItemLoaderPtr &loader, QSettings *settings) const
+{
+    settings->beginGroup(loader->id());
+
+    QVariantMap s;
+    for (const auto &name : settings->allKeys()) {
+        s[name] = settings->value(name);
+    }
+    const auto enabled = settings->value("enabled", true).toBool();
+    loader->loadSettings(s);
+
+    settings->endGroup();
+
+    return enabled;
+}
