@@ -89,9 +89,8 @@ QString getDesktopFilename()
 void printFileError(const QFile &file, const char *message, LogLevel logLevel = LogError)
 {
     log( QString("%1 \"%2\": %3")
-         .arg(message)
-         .arg(file.fileName())
-         .arg(file.errorString()), logLevel );
+         .arg( QString::fromLatin1(message), file.fileName(), file.errorString()),
+         logLevel );
 }
 
 void maybePrintFileError(const QFile &file, const char *message)
@@ -220,7 +219,7 @@ void X11Platform::setAutostartEnabled(bool enable)
     desktopFile2.write("Exec=" + cmd.toUtf8() + "\n");
 
     desktopFile2.write("Hidden=");
-    desktopFile2.write(enable ? "False" : "True");
+    desktopFile2.write(enable ? "false" : "true");
     desktopFile2.write("\n");
 
     desktopFile2.write("X-GNOME-Autostart-enabled=");
@@ -232,7 +231,7 @@ void X11Platform::setAutostartEnabled(bool enable)
 
     maybePrintFileError(desktopFile2, "Failed to write desktop file");
 #else
-    Q_UNUSED(enable);
+    Q_UNUSED(enable)
 #endif
 }
 
@@ -291,10 +290,10 @@ bool X11Platform::findPluginDir(QDir *pluginsDir)
 {
     pluginsDir->setPath( qApp->applicationDirPath() );
 
-    if ( pluginsDir->dirName() == QString("bin")
+    if ( pluginsDir->dirName() == QLatin1String("bin")
          && pluginsDir->cdUp()
-         && (pluginsDir->cd("lib64") || pluginsDir->cd("lib"))
-         && pluginsDir->cd("copyq") )
+         && (pluginsDir->cd(QLatin1String("lib64")) || pluginsDir->cd(QLatin1String("lib")))
+         && pluginsDir->cd(QLatin1String("copyq")) )
     {
         // OK, installed in /usr/local/bin or /usr/bin.
         return true;
@@ -302,9 +301,9 @@ bool X11Platform::findPluginDir(QDir *pluginsDir)
 
     pluginsDir->setPath( qApp->applicationDirPath() );
 
-    if ( pluginsDir->cd("plugins") ) {
+    if ( pluginsDir->cd(QLatin1String("plugins")) ) {
         // OK, plugins in same directory as executable.
-        pluginsDir->cd("copyq");
+        pluginsDir->cd(QLatin1String("copyq"));
         return true;
     }
 
@@ -313,7 +312,7 @@ bool X11Platform::findPluginDir(QDir *pluginsDir)
 
 QString X11Platform::defaultEditorCommand()
 {
-    return "gedit --standalone -- %1";
+    return QLatin1String("gedit --standalone -- %1");
 }
 
 QString X11Platform::translationPrefix()
